Store

Struct Store 

pub struct Store<K, V> { /* private fields */ }

Implementations

Source

impl<K, V> Store<K, V>
where K: Debug + Clone + From<ByteView> + Ord + Eq + Hash, V: Debug + Clone + From<ByteView>, ByteView: From<K> + From<V>, Self: Send + Sync,

pub fn import( db: &Database, path: &Path, name: &str, version: Version, mode: Mode, kind: Kind, ) -> Result<Self>

pub fn import_cached( db: &Database, path: &Path, name: &str, version: Version, mode: Mode, kind: Kind, max_batches: u8, ) -> Result<Self>

pub fn get<'a>(&'a self, key: &'a K) -> Result<Option<Cow<'a, V>>>

pub fn is_empty(&self) -> Result<bool>

pub fn insert(&mut self, key: K, value: V)

pub fn remove(&mut self, key: K)

pub fn clear_caches(&mut self)

Clear all caches. Call after bulk removals (e.g., rollback) to prevent stale reads.

pub fn take_pending_ingest( &mut self, height: Height, ) -> Result<Option<Box<dyn FnOnce() -> Result<()> + Send>>>
where K: Send + 'static, V: Send + 'static, for<'a> ByteView: From<&'a K> + From<&'a V>,

Takes buffered puts/dels and returns a closure that ingests them into the keyspace. The store is left with empty buffers, ready for the next batch.

pub fn iter(&self) -> impl Iterator<Item = (K, V)>

pub fn prefix<P: AsRef<[u8]>>( &self, prefix: P, ) -> impl DoubleEndedIterator<Item = (K, V)> + '_

pub fn approximate_len(&self) -> usize

pub fn needs(&self, height: Height) -> bool