pub struct Store<K, V> { /* private fields */ }Implementations
Sourceimpl<K, V> Store<K, V>
impl<K, V> Store<K, V>
pub fn import( db: &Database, path: &Path, name: &str, version: Version, mode: Mode, kind: Kind, ) -> Result<Self>
pub fn import_cached( db: &Database, path: &Path, name: &str, version: Version, mode: Mode, kind: Kind, max_batches: u8, ) -> Result<Self>
pub fn get<'a>(&'a self, key: &'a K) -> Result<Option<Cow<'a, V>>>
pub fn is_empty(&self) -> Result<bool>
pub fn insert(&mut self, key: K, value: V)
pub fn remove(&mut self, key: K)
Sourcepub fn clear_caches(&mut self)
pub fn clear_caches(&mut self)
Clear all caches. Call after bulk removals (e.g., rollback) to prevent stale reads.
Sourcepub fn take_pending_ingest(
&mut self,
height: Height,
) -> Result<Option<Box<dyn FnOnce() -> Result<()> + Send>>>
pub fn take_pending_ingest( &mut self, height: Height, ) -> Result<Option<Box<dyn FnOnce() -> Result<()> + Send>>>
Takes buffered puts/dels and returns a closure that ingests them into the keyspace. The store is left with empty buffers, ready for the next batch.
pub fn iter(&self) -> impl Iterator<Item = (K, V)>
pub fn prefix<P: AsRef<[u8]>>( &self, prefix: P, ) -> impl DoubleEndedIterator<Item = (K, V)> + '_
pub fn approximate_len(&self) -> usize
pub fn needs(&self, height: Height) -> bool